###############################################################################
# Name: 
#   playblast_demo.py
#
# Description: 
#   Example that creates a playblast with a dynamically 
#   generated shot mask
#
# Author: 
#   Chris Zurbrigg (http://zurbrigg.com)
#
# Copyright (C) 2013 Chris Zurbrigg. All rights reserved.
###############################################################################

import maya.cmds as cmds
import maya.OpenMaya as om

from shot_mask import ShotMask

def playblast_demo():
    '''
    Creates a playblast with a dynamically generated shot mask
    '''
    
    # Get the camera for the active panel (to be playblasted)
    panel = cmds.getPanel(withFocus=True)
    if (cmds.getPanel(typeOf=panel) == "modelPanel"):
        camera = cmds.modelEditor(panel, q=True, camera=True)
    else:
        om.MGlobal.displayWarning("Playblast viewport no available")
        return
    
    # Setup and create the shot mask
    ShotMask.restore_defaults()
    
    # Windows specific font. This will vary on other OSes
    ShotMask.set_label_font("Lucida Console|w400|h-11")
    
    for i in range(0, 6):
        ShotMask.set_label_text(i, "")
        ShotMask.set_label_scale(i, 0.8)
        
    ShotMask.set_label_text(3, "shot_001_0010")
    ShotMask.set_label_offset(3, 0.0005, 0.0003)
    ShotMask.set_label_text(5, "Chris Zurbrigg")
    ShotMask.set_label_offset(5, -0.0005, 0.0003)
    ShotMask.set_counter_position(1)
    
    ShotMask.create()
    
    # Disable the display gates and eliminate overscan
    # Shot mask should fill the playblast window
    display_film_gate = cmds.camera(camera, q=True, displayFilmGate=True)
    display_resolution = cmds.camera(camera, q=True, displayResolution=True)
    overscan = cmds.camera(camera, q=True, overscan=True)
    cmds.camera("persp", e=True, 
                displayFilmGate=False, 
                displayResolution=False, 
                overscan=1.0)

    # Get the playblast size from the render settings
    render_width = cmds.getAttr("defaultResolution.width")
    render_height = cmds.getAttr("defaultResolution.height")

    cmds.playblast(format="image",
                   forceOverwrite=True,
                   showOrnaments=False,
                   widthHeight=(render_width, render_height),
                   percent=100)
    
    # Restore gates to pre-playblast state
    cmds.camera(camera, e=True, 
                displayFilmGate=display_film_gate, 
                displayResolution=display_resolution, 
                overscan=overscan)
    
    # Cleanup the mask
    ShotMask.delete()
    
if __name__ == "__main__":
    playblast_demo()
    